netapp_ontap.models.volume_space_snapshot_autodelete API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_space_snapshot_autodelete`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeSpaceSnapshotAutodeleteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeSpaceSnapshotAutodelete object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `commitment: str GET PATCH`

    By default, snapshot autodelete does not delete snapshots locked by Snapmirror, clones of a volume, a LUN, an NVMe namespace, or a file. Deletion of snapshots locked by these applications is specified using this option. The default value is try.

    Valid choices:

    - try
    - disrupt
    - destroy
  `defer_delete: str GET PATCH`

    Allows the user to inform snapshot autodelete to defer the deletion of a specified snapshot until the end. The default value is user_created.

    Valid choices:

    - scheduled
    - user_created
    - prefix
    - none
  `delete_order: str GET PATCH`

    Specifies the order in which snapshot autodelete occurs. Ordering is done using the date and time the snapshot is created. The default value is oldest_first.

    Valid choices:

    - newest_first
    - oldest_first
  `enabled: bool PATCH`

    Specifies whether snapshot autodelete is currently enabled on this volume.

  `prefix: str GET PATCH`

    Specifies the prefix of the snapshot which if matched, is deleted last. Used with autodelete_defer_delete when used with a prefix value.

  `target_free_space: Size GET PATCH`

    Snapshots are deleted, one at a time, until the used volume space reaches the value specified. The default is 20% free space or 80% utilized.

  `trigger: str GET PATCH`

    Specifies when the system should trigger an autodelete of snapshots. When set to volume, autodelete is triggered based on volume fullness. When set to snap_reserve, autodelete is triggered based on snapshot reserve fullness. The default value is volume.

    Valid choices:

    - volume
    - snap_reserve